![PyScreen Logo](https://gitlab.com/jvadair/pyscreen/-/raw/master/banner.png)
# PyScreen
A simple python wrapper for GNU Screen

### Installation
`pip3 install python-screen`

### Documentation
If you would like to help with the documentation, please email [dev@jvadair.com](mailto:dev@jvadair.com)